==> ORBit-0.3.96.tar.gz: ORBit-0.3.96/src/orb/orbit_types.h <==
/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */

/*
 *  ORBit: A CORBA v2.2 ORB
 *
 *  Copyright (C) 1998 Richard H. Porter and Red Hat Software
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Library General Public
 *  License as published by the Free Software Foundation; either
 *  version 2 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Library General Public License for more details.
 *
 *  You should have received a copy of the GNU Library General Public
 *  License along with this library; if not, write to the Free
 *  Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *  Author: Dick Porter <dick@cymru.net>
 *
 */

#ifndef _ORBIT_TYPES_H_
#define _ORBIT_TYPES_H_

#include <stddef.h>	/* for wchar_t */
#include <sys/types.h>  /* for sysdep types */
#include <netinet/in.h>	/* for sockaddr_in */
#include <sys/uio.h> /* for struct iovec */

#include <ORBitutil/basic_types.h>

#define CORBA_TRUE 1
#define CORBA_FALSE 0

typedef CORBA_char *CORBA_ORBid;

typedef CORBA_unsigned_long CORBA_ServiceOption;
typedef CORBA_unsigned_long CORBA_ServiceDetailType;

#include "corba_orb.h"

/*
 * CORBA_RepositoryId and CORBA_Identifier are defined in the Interface
 * Repository, but are needed in other interfaces in the ORB itself.
 */
#ifndef _CORBA_RepositoryId_defined
#define _CORBA_RepositoryId_defined

typedef CORBA_char *CORBA_RepositoryId;

#endif /* !_CORBA_RepositoryId_defined */

#ifndef _CORBA_Identifier_defined
#define _CORBA_Identifier_defined

typedef CORBA_char *CORBA_Identifier;

#endif /* !_CORBA_Identifier_defined */

#include "corba_any.h"

typedef struct CORBA_ServiceDetail_type CORBA_ServiceDetail;
typedef struct CORBA_Request_type *CORBA_Request;
typedef struct CORBA_ServerRequest_type *CORBA_ServerRequest;
typedef CORBA_char *CORBA_Context;
typedef struct CORBA_DynFixed_type CORBA_DynFixed;
typedef struct CORBA_DynAny_type CORBA_DynAny;
typedef struct CORBA_DynEnum_type CORBA_DynEnum;
typedef struct CORBA_DynStruct_type CORBA_DynStruct;
typedef struct CORBA_DynUnion_type CORBA_DynUnion;
typedef struct CORBA_DynSequence_type CORBA_DynSequence;
typedef struct CORBA_DynArray_type CORBA_DynArray;
typedef struct CORBA_Current_type CORBA_Current;

#include "corba_portableserver.h"

#include "corba_env.h"

#include "corba_sequences_type.h"

#include "corba_basic_sequences_type.h"

#include "corba_object.h"

#include "orbit_object_type.h"

#include "corba_object_type.h"

#include "corba_orb_type.h"

typedef void CORBA_Status;

typedef unsigned int CORBA_enum;


#include "corba_typecode.h"
#include "corba_typecode_type.h"
#include "corba_any_type.h"
#include "corba_any_proto.h"

/* 19.14 */

/* XXX */
typedef struct CORBA_fixed_d_s {
	CORBA_unsigned_short _digits;
	CORBA_short _scale;
	signed char _sign;
	signed char _value[1];
} CORBA_fixed_d_s;

#include "corba_env_type.h"


typedef struct CORBA_WrongTransaction {
	int dummy;
} CORBA_WrongTransaction;

typedef CORBA_unsigned_long CORBA_Flags;

#define CORBA_ARG_IN (1<<0)
#define CORBA_ARG_OUT (1<<1)
#define CORBA_ARG_INOUT (1<<2)
#define CORBA_CTX_RESTRICT_SCOPE (1<<3)
#define CORBA_CTX_DELETE_DESCENDENTS (1<<4)
#define CORBA_OUT_LIST_MEMORY (1<<5)
#define CORBA_IN_COPY_VALUE (1<<6)
#define CORBA_DEPENDENT_LIST (1<<7)
#define CORBA_INV_NO_RESPONSE (1<<8)
#define CORBA_INV_TERM_ON_ERROR (1<<9)
#define CORBA_RESP_NO_WAIT (1<<10)

typedef struct CORBA_NamedValue {
	CORBA_Identifier name;		/* argument name */
	CORBA_any argument;		/* argument */
	CORBA_long len;			/* length/count of argument value */
	CORBA_Flags arg_modes;		/* argument mode flags */
} CORBA_NamedValue;

typedef struct CORBA_NVList_type {
	CORBA_Flags flags;
	GArray *list;
} CORBA_NVList;

typedef struct CORBA_DynAny_Invalid {
	int dummy;
} CORBA_DynAny_Invalid;

typedef struct CORBA_DynAny_InvalidValue {
	int dummy;
} CORBA_DynAny_InvalidValue;

typedef struct CORBA_DynAny_TypeMismatch {
	int dummy;
} CORBA_DynAny_TypeMismatch;

typedef struct CORBA_DynAny_InvalidSeq {
	int dummy;
} CORBA_DynAny_InvalidSeq;

typedef struct CORBA_DynFixed_Invalid {
	int dummy;
} CORBA_DynFixed_Invalid;

typedef struct CORBA_DynFixed_InvalidValue {
	int dummy;
} CORBA_DynFixed_InvalidValue;

typedef struct CORBA_DynFixed_TypeMismatch {
	int dummy;
} CORBA_DynFixed_TypeMismatch;

typedef struct CORBA_DynFixed_InvalidSeq {
	int dummy;
} CORBA_DynFixed_InvalidSeq;

struct CORBA_DynFixed_type {
	int fill_me_in;
};

struct CORBA_DynAny_type {
	int fill_me_in;
};

typedef struct CORBA_DynEnum_Invalid {
	int dummy;
} CORBA_DynEnum_Invalid;

typedef struct CORBA_DynEnum_InvalidValue {
	int dummy;
} CORBA_DynEnum_InvalidValue;

typedef struct CORBA_DynEnum_TypeMismatch {
	int dummy;
} CORBA_DynEnum_TypeMismatch;

typedef struct CORBA_DynEnum_InvalidSeq {
	int dummy;
} CORBA_DynEnum_InvalidSeq;

struct CORBA_DynEnum_type {
	int fill_me_in;
};

typedef CORBA_char *CORBA_FieldName;

typedef struct CORBA_NameValuePair {
	CORBA_FieldName id;
	CORBA_any value;
} CORBA_NameValuePair;

typedef struct CORBA_DynStruct_Invalid {
	int dummy;
} CORBA_DynStruct_Invalid;

typedef struct CORBA_DynStruct_InvalidValue {
	int dummy;
} CORBA_DynStruct_InvalidValue;

typedef struct CORBA_DynStruct_TypeMismatch {
	int dummy;
} CORBA_DynStruct_TypeMismatch;

typedef struct CORBA_DynStruct_InvalidSeq {
	int dummy;
} CORBA_DynStruct_InvalidSeq;

struct CORBA_DynStruct_type {
	int fill_me_in;
};

typedef struct CORBA_DynUnion_Invalid {
	int dummy;
} CORBA_DynUnion_Invalid;

typedef struct CORBA_DynUnion_InvalidValue {
	int dummy;
} CORBA_DynUnion_InvalidValue;

typedef struct CORBA_DynUnion_TypeMismatch {
	int dummy;
} CORBA_DynUnion_TypeMismatch;

typedef struct CORBA_DynUnion_InvalidSeq {
	int dummy;
} CORBA_DynUnion_InvalidSeq;

struct CORBA_DynUnion_type {
	int fill_me_in;
};

typedef struct CORBA_DynSequence_Invalid {
	int dummy;
} CORBA_DynSequence_Invalid;

typedef struct CORBA_DynSequence_InvalidValue {
	int dummy;
} CORBA_DynSequence_InvalidValue;

typedef struct CORBA_DynSequence_TypeMismatch {
	int dummy;
} CORBA_DynSequence_TypeMismatch;

typedef struct CORBA_DynSequence_InvalidSeq {
	int dummy;
} CORBA_DynSequence_InvalidSeq;

struct CORBA_DynSequence_type {
	int fill_me_in;
};

typedef struct CORBA_DynArray_Invalid {
	int dummy;
} CORBA_DynArray_Invalid;

typedef struct CORBA_DynArray_InvalidValue {
	int dummy;
} CORBA_DynArray_InvalidValue;

typedef struct CORBA_DynArray_TypeMismatch {
	int dummy;
} CORBA_DynArray_TypeMismatch;

typedef struct CORBA_DynArray_InvalidSeq {
	int dummy;
} CORBA_DynArray_InvalidSeq;

struct CORBA_DynArray_type {
	int fill_me_in;
};

struct CORBA_Current_type {
	int fill_me_in;
};

#include "corba_portableserver_type.h"

typedef CORBA_unsigned_short CORBA_ServiceType;

#define CORBA_Security (1)

struct CORBA_ServiceDetail_type {
	CORBA_ServiceDetailType service_detail_type;
	CORBA_sequence_octet service_detail;
};

typedef struct CORBA_ServiceInformation_struct {
	CORBA_sequence_ServiceOption service_options;
	CORBA_sequence_ServiceDetail service_details;
} CORBA_ServiceInformation;

#endif /* !_ORBIT_TYPES_H_ */

==> ORBit-0.4.93.tar.gz: ORBit-0.4.93/src/orb/orbit_types.h <==
/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */

/*
 *  ORBit: A CORBA v2.2 ORB
 *
 *  Copyright (C) 1998 Richard H. Porter and Red Hat Software
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Library General Public
 *  License as published by the Free Software Foundation; either
 *  version 2 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Library General Public License for more details.
 *
 *  You should have received a copy of the GNU Library General Public
 *  License along with this library; if not, write to the Free
 *  Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *  Author: Dick Porter <dick@cymru.net>
 *
 */

#ifndef _ORBIT_TYPES_H_
#define _ORBIT_TYPES_H_

#include <stddef.h>	/* for wchar_t */
#include <sys/types.h>  /* for sysdep types */
#include <netinet/in.h>	/* for sockaddr_in */
#include <sys/uio.h> /* for struct iovec */

#include <ORBitutil/basic_types.h>

#define CORBA_TRUE 1
#define CORBA_FALSE 0

typedef CORBA_char *CORBA_ORBid;

typedef CORBA_unsigned_long CORBA_ServiceOption;
typedef CORBA_unsigned_long CORBA_ServiceDetailType;

#include "corba_orb.h"

/*
 * CORBA_RepositoryId and CORBA_Identifier are defined in the Interface
 * Repository, but are needed in other interfaces in the ORB itself.
 */
#ifndef _CORBA_RepositoryId_defined
#define _CORBA_RepositoryId_defined

typedef CORBA_char *CORBA_RepositoryId;

#define CORBA_RepositoryId__free CORBA_string__free
#define CORBA_sequence_RepositoryId_allocbuf CORBA_sequence_CORBA_string_allocbuf
#endif /* !_CORBA_RepositoryId_defined */

#ifndef _CORBA_Identifier_defined
#define _CORBA_Identifier_defined

typedef CORBA_char *CORBA_Identifier;

#define CORBA_Identifier__free CORBA_string__free
#define CORBA_sequence_Identifier_allocbuf CORBA_sequence_CORBA_string_allocbuf
#endif /* !_CORBA_Identifier_defined */

#include "corba_any.h"

typedef struct CORBA_ServiceDetail_type CORBA_ServiceDetail;
typedef struct CORBA_Request_type *CORBA_Request;
typedef struct CORBA_ServerRequest_type *CORBA_ServerRequest;
typedef CORBA_char *CORBA_Context;
typedef struct CORBA_DynFixed_type *CORBA_DynFixed;
typedef struct CORBA_Current_type *CORBA_Current;

#include "corba_portableserver.h"

#include "corba_env.h"

#include "corba_sequences_type.h"

#include "corba_basic_sequences_type.h"

#include "corba_object.h"

#include "orbit_object_type.h"

#include "corba_object_type.h"

#include "corba_orb_type.h"

typedef void CORBA_Status;

typedef CORBA_unsigned_long CORBA_enum;

#include "corba_typecode.h"
#include "corba_typecode_type.h"
#include "corba_any_type.h"
#include "corba_any_proto.h"

/* 19.14 */

/* XXX */
typedef struct CORBA_fixed_d_s {
	CORBA_unsigned_short _digits;
	CORBA_short _scale;
	signed char _sign;
	signed char _value[1];
} CORBA_fixed_d_s;

#include "corba_env_type.h"


typedef struct CORBA_WrongTransaction {
	int dummy;
} CORBA_WrongTransaction;

typedef CORBA_unsigned_long CORBA_Flags;

#define CORBA_ARG_IN (1<<0)
#define CORBA_ARG_OUT (1<<1)
#define CORBA_ARG_INOUT (1<<2)
#define CORBA_CTX_RESTRICT_SCOPE (1<<3)
#define CORBA_CTX_DELETE_DESCENDENTS (1<<4)
#define CORBA_OUT_LIST_MEMORY (1<<5)
#define CORBA_IN_COPY_VALUE (1<<6)
#define CORBA_DEPENDENT_LIST (1<<7)
#define CORBA_INV_NO_RESPONSE (1<<8)
#define CORBA_INV_TERM_ON_ERROR (1<<9)
#define CORBA_RESP_NO_WAIT (1<<10)

typedef struct CORBA_NamedValue {
	CORBA_Identifier name;		/* argument name */
	CORBA_any argument;		/* argument */
	CORBA_long len;			/* length/count of argument value */
	CORBA_Flags arg_modes;		/* argument mode flags */
} CORBA_NamedValue;

typedef struct CORBA_NVList_type {
	CORBA_Flags flags;
	GArray *list;
} CORBA_NVList;

typedef CORBA_char *CORBA_FieldName;

typedef struct CORBA_NameValuePair {
	CORBA_FieldName id;
	CORBA_any value;
} CORBA_NameValuePair;

struct CORBA_Current_type {
	int fill_me_in;
};

#include "corba_portableserver_type.h"

typedef CORBA_unsigned_short CORBA_ServiceType;

#define CORBA_Security (1)

struct CORBA_ServiceDetail_type {
	CORBA_ServiceDetailType service_detail_type;
	CORBA_sequence_octet service_detail;
};

typedef struct CORBA_ServiceInformation_struct {
	CORBA_sequence_ServiceOption service_options;
	CORBA_sequence_ServiceDetail service_details;
} CORBA_ServiceInformation;

#endif /* !_ORBIT_TYPES_H_ */
